Idaho Court of Appeals Criminal Opinions | Supreme Court

Skip to main content

# STATE OF IDAHO JUDICIAL BRANCH
Supreme Court Appeals

## Search form

Search

## Court of Appeals - Criminal-Post Conviction Opinions

The Idaho Supreme Court and Idaho Court of Appeals cited opinions are made available online as a public service. All cited opinions are posted the day of their release. West Publishing Company publishes all cited opinions in the Pacific Reporter and Idaho Reports volumes. All cited opinions are removed from this site one-year upon release.

NOTICE: These opinions are subject to formal revision before publication in the preliminary print of the Pacific Reporter. Readers are requested to notify the Clerk of the Court/Reporter of Decisions, Supreme Court of Idaho, Boise, Idaho, 83720-0101, of any typographical or other formal errors, in order that corrections may be made before the preliminary print goes to press.

### By Release Date

- - Release Date | Docket# | Case Name | Opinion | Notes
    Feb 25, 2016 | 42572 | State v. Conner Blaine Hoy | Opinion | Robbery & aggravated assault
    Feb 25, 2016 | 42806 | State v. Brian Ellis Neal | Opinion | The State appeals from judgment granting motion to suppress.
    Feb 23, 2016 | 43077 | State v. James W. Clark | Opinion | Misdemeanor trespass
    Feb 18, 2016 | 42554 | State v. Vernon Craig Pelland | Opinion | Grand theft by possession
    Feb 16, 2016 | 43092 | State v. Anthony Kyle Smith | Opinion | Appeal from order denying motion to suppress.
    Feb 12, 2016 | 43123 | State v. Michael P. Martin | Opinion | Appeal from order denying motion for credit for time served.
    Feb 10, 2016 | 42506 | Joshua McGiboney v. State | Opinion | POST-CONVICTION Robbery, aggravated battery, burglary, possession of a firearm
    Feb 10, 2016 | 43263 | State v. Kevin Donald Cheatham | Opinion | Appeal from order denying motion to amend judgment (grand theft by possession of stolen property)
    Feb 1, 2016 | 42090 | State v. Laura Lee Smith | Opinion | SUBSTITUTE: Aiding and abetting in the delivery of a controlled substance.
    Jan 27, 2016 | 42780 | Alik G. Takhsilov v. State | Opinion | POST-CONVICTION Robbery; burglary
    Jan 27, 2016 | 42769 | State v. Dennis James Garner | Opinion | Battery on a correctional officer
    Jan 14, 2016 | 43055 | State v. John Scott Meier | Opinion | Appeal from denial of Rule 35 Motion Re sentence for possession of sexually exploitative material
    Jan 8, 2016 | 42321 | State v. John Patrick Linze, Jr. | Opinion | Appeal from denial of motion to suppress
    Jan 7, 2016 | 42637 | State v. Natasha Lynn Bly | Opinion | Appeal from denial of motion to suppress
    Jan 6, 2016 | 42790 | State v. Lori Elizabeth Lovely | Opinion | Appeal from denial of motion to suppress
    Dec 31, 2015 | 43388 | State v. James Butler Ramsey | Opinion | Appeal from Order denying Rule 35 Motion to correct illegal sentence for robbery, grand theft and aggravated assault.
    Dec 31, 2015 | 42362 | State v. Jose Antonio Ruiz | Opinion | Lewd conduct with a minor; sexual abuse of a child
    Dec 31, 2015 | 41834 | Tyrell Ramsey v. State | Opinion | SUBSTITUTE OPINION. POST-CONVICTION (rape and battery)
    Dec 23, 2015 | 42848 | State v. Brian W. Pierce | Opinion | State appeals district court vacating judgment of conviction for violating a domestic violence protection order.
    Dec 15, 2015 | 42340 | Gary W. Mallory, II v. State | Opinion | POST-CONVICTION (murder)
    Dec 10, 2015 | 42436 | State v. Emil Mercado | Opinion | Lewd conduct with a minor.
    Dec 9, 2015 | 42363 | State v. Keith L. Case | Opinion | Motion to suppress
    Dec 8, 2015 | 42335 | State v. Scott Lewis Ostler | Opinion | Lewd conduct with a minor.
    Dec 4, 2015 | 41916 | State v. William Dee Van Komen, Jr. | Opinion | Appeal from order relinquishing jurisdiction; possession of a controlled substance.
    Dec 4, 2015 | 42098 | State v. Marcos Apollo Jimenez | Opinion | Sexual battery of a minor
    Nov 20, 2015 | 42498 | Mitchell James Bias v. State | Opinion | POST-CONVICTION: Conspiracy to commit robbery and burglary.
    Nov 17, 2015 | 41730 | State v. Arnold Dean Anderson | Opinion | Possession of controlled substance; denial of motion to suppress and denial of Rule 35 motion to reduce sentence.
    Nov 10, 2015 | 42680 | State v. Thomas C. Kelley | Opinion | Trafficking - marijuana
    Nov 6, 2015 | 42655 | State v. Michel J. Walker | Opinion | Appeal from order granting State's motion to reconsider reduction of sentence.
    Nov 4, 2015 | 42749 | State v. Jacob Steven Davis | Opinion | Motion to suppress.
    Nov 4, 2015 | 42799 | State v. Rey Alfredo Ornelas | Opinion | Appeal from the decision denying Batson challenge.
    Nov 3, 2015 | 42870 | State v. Nicholas Tate Vance | Opinion | Burglary
    Nov 2, 2015 | 42095 | Wally Kay Schultz v. State | Opinion | POST-CONVICTION (battery)
    Oct 30, 2015 | 42636 | State v. Wayne Ray Floyd | Opinion | Possession of controlled substance; motion to suppress
    Oct 29, 2015 | 42532 | State v. Michael Brian Wilson | Opinion | aggravated assault with intent to promote gang activity
    Oct 21, 2015 | 40916 | State v. Robert Dean Hall | Opinion | Second-degree murder
    Oct 20, 2015 | 42525 | State v. Joseph R. Rockstahl | Opinion | Disturbing the peace; exhibiting a deadly weapon
    Oct 14, 2015 | 40999 | State v. Doris Nepa Hays | Opinion | State appeals district court order granting motion to suppress.
    Oct 7, 2015 | 42242 | Christopher A. Pentico v. State | Opinion | POST-CONVICTION (tresspass)
    Oct 2, 2015 | 42155 | State v. Juan Roberto Jimenez | Opinion | Aggravated battery
    Oct 1, 2015 | 41740 | Peter Trejo Mora v. State | Opinion | POST-CONVICTION (rape)
    Sept 24, 2015 | 42682 | Jonna Lynn Bobeck v. Transportation | Opinion | Driver's license suspension
    Sept 16, 2015 | 42198 | State v. Jose Luis Villavicencio | Opinion | State appeals amended judgment modifying probation terms.
    Sept 8, 2015 | 42691 | State v. Jon Steven Huffaker | Opinion | State appeals order suppressing oral and written statements.
    Sept 3, 2015 | 42447 | State v. Stephen P. Rozajewski | Opinion | Unlawful possession of a firearm.
    August 26, 2015 | 42097 | State v. Freddie Anthony Naranjo | Opinion | Motion to suppress.
    August 24, 2015 | 41942 | Cullen R. Sims v. State | Opinion | Appeal from dismissal of motion to suppress blood test results.
    August 17, 2015 | 42277 | State v. Kerry Allen Howell | Opinion | Burglary
    August 14, 2015 | 42787 | State v. Scott Andrew Kinch | Opinion | Denial of Motion to Suppress
    August 14, 2015 | 42153 | Richard Myers Caldwell V. State | Opinion | POST-CONVICTION. Ineffective counsel
    July 30, 2015 | 42699 | State v. Karlie Lynn Meyer | Opinion | Possession of methamphetamine.
    July 22, 2015 | 42377 | State v. Joseph Alan Knight (OPINION VACATED. SEE ATTACHED ORDER) | ORDER | Possession of controlled substance.
    July 21, 2015 | 42160 | Diego Peregrina v. State | Opinion | POST-CONVICTION. Aggravated battery.
    July 17, 2015 | 41902 | State v. Shayne Ray Burgess | Opinion | Aggravated assault.
    July 14, 2015 | 40767 | State v. Terry Lin Smith | Opinion | Lewd conduct with minor under sixteen.
    July 9, 2015 | 42405 | State v. Scott Alan Moore | Opinion | Appeal from denial of motion to reduce felony to a misdemeanor.
    July 9, 2015 | 41671 | State v. Edward Ray Christensen | Opinion | Motion to suppress possession of controlled substance.
    July 7, 2015 | 42115 | State v. Robert Michael Williston | Opinion | Attempted strangulation.
    July 7, 2015 | 42022 | State v. Tristum Beeks, II | Opinion | No-contact order.
    July 6, 2015 | 41831 | State v. Ashli Marie Easterday | Opinion | Motion to suppress possession of controlled substance.
    June 24, 2015 | 42229 | State v. Jason Ephriam Rowland | Opinion | Motion to suppress possession of controlled substance.
    June 24, 2015 | 42420 | State v. Jacob Taylor Rainier | Opinion | Possession of marijuana with intent to deliver.
    June 19, 2015 | 42397 | State v. Kurtis Thomas Kelly | Opinion | Battery on a law enforcement officer
    June 15, 2015 | 41661 | State v. Kenneth Randall Smith | Opinion | Aggravated assault; aggravated battery; DUI; possession of methamphetamine.
    June 15, 2015 | 42070 | State v. Michael Douglas White | Opinion | Appeal from order revoking probation
    May 29, 2015 | 41981 | State v. Heather Lynn Heard | Opinion | Appeal from denial of suppression motion
    May 28, 2015 | 42169 | State v. Dona Nichoeal Westlake | Opinion | State's appeal from order granting suppression motion
    May 27, 2015 | 41995 | Juan Manuel Arellano v. State | Opinion | POST-CONVICTION - Ineffective assistance of defense counsel claim
    May 22, 2015 | 41790 | State v. Russell Glenn Davis | Opinion | Possession of controlled substance with intent to deliver.
    May 19, 2015 | 41821-41822 | State v. Leroy S. Wilske | Opinion | DUI (alcohol); possession of controlled substance; possession of drug paraphernalia.
    May 15, 2015 | 40759 | State v. Justin Lee Wilson | Opinion | Appeal from denial of motions to exclude witness & to continue trial. (DUI)
    May 15, 2015 | 42103 | State v. Domingo Jesus Diaz | Opinion | SUBSTITUTE OPINON - Battery and assault with the intent to commit rape. The Court's prior OPINION dated May 6, 2015 is WITHDRAWN.
    May 13, 2015 | 41677 | Richard Joseph Wagner v. State | Opinion | Lewd conduct with a child under 16. The Court's prior UNPUBLISHED Opinion issued March 4, 2015 is WITHDRAWN.
    May 13, 2015 | 41675 | State v. Corey Steven Kubat | Opinion | Possession of controlled substance
    May 4, 2015 | 41549 | State v. John Joseph Fairchild | Opinion | Grand theft
    Apr 27, 2015 | 41414 | Robert Terry Johnson v. State | Opinion | Post-Conviction. First-degree murder
    Apr 8, 2015 | 41063 | State v. Brant Lee Eversole | Opinion | DUI; motion to suppress (warrantless blood draw)
    Apr 7, 2015 | 41913 | State v. Wade Allen Tomlinson | Opinion | DUI (breath alcohol test results)
    Apr 6, 2015 | 42202 | State v. Jodie Marie Edwards | Opinion | Possession of a controlled substance
    Apr 2, 2015 | 41603 | State v. Brian Neil Pratt | Opinion | Delivery & trafficking of a controlled substance
    Mar 30, 2015 | 41497 | State v. Gerald K. Umphenour | Opinion | Possession - Methamphetamine
    Mar 13, 2015 | 41824 | State v. Kelsey Rose Hopkins | Opinion | SUBSTITUTE OPINION - Malicious injury to property
    Feb 25, 2015 | 41832 | State v. Victoria Bea Morin | Opinion | Driving under the influence of drugs
    Feb 25, 2015 | 41594 | State v. Angela Marie Boehm | Opinion | DUI without privileges
    Feb 18, 2015 | 41933 | State v. Richard Glenn Morris | Opinion | Motion to suppress
    Feb 17, 2015 | 40038 | State v. Matthew James Gonzales | Opinion | Motion to withdraw guilty plea - folony injury to a child
    Feb 13, 2015 | 41539 | State v. Dwayne Allan Bradley | Opinion | Trafficking - methamphetamine
    Feb 12, 2015 | 41458 | State v. Dustin Thomas Armstrong | Opinion | Motion to suppress
    Feb 11, 2015 | 41890 | Haris Keserovic v. State | Opinion | Post-Conviction. A plea of guilty to an aggravated felony resulted in deportation. State appeals from reversal of grant for summary dismissal of petition for PC relief
    Jan 15, 2015 | 41288 | State v. Russell Allen Passons | Opinion | Aggravated assault & burglary
    Jan 13, 2015 | 41240 | Dennis Raymond Heilman v. State | Opinion | Appeal from summary dismissal of successive petition for post-conviction relief. - Rape / aggravated assault
    Jan 8, 2015 | 42024 | State v. Michelle Alece Mace | Opinion | Appeal from order rescinding credit for time served
    Dec 23, 2014 | 41772/41773 | Tarango DeForest Padilla v. State | Opinion | Post-Conviction - Ineffective assistance
    Dec 19, 2014 | 41462 | State v. Jonathan A. Collins | Opinion | Lewd conduct with minor under sixteen
    Dec 19, 2014 | 41236 | State v. James D. Kirk | Opinion | Lewd conduct with minor under sixteen
    Dec 17, 2014 | 41862 | State v. Murray Casey Carter | Opinion | DUI; felony eluding
    Dec 16, 2014 | 41762 | State v. Gaylord Jay Colvin | Opinion | State appeals from district court's reversal of magistrate's order denying motion to suppress
    Dec 10, 2014 | 41997-41998 | State v. John Huey Daniels | Opinion | State appeals from district court's dismissal of appeals in the decision to dismiss the complaint charging destruction of insured property
    Dec 4, 2014 | 41892 | State v. Shepherd Reale | Opinion | Sexual abuse of a child under sixteen; restitution order
    Dec 4, 2014 | 41015 | State v. John M. Barber | Opinion | Possession of marijuana
    Dec 3, 2014 | 40855 | State v. Tami Marie Southwick | Opinion | Possession of methamphetamine
    Dec 3, 2014 | 40895 | State v. Kirk Julliard Gosch | Opinion | Manufacturing of, possession of and intent to deliver marijuana
    Nov 25, 2014 | 40733 | State v. Arthur Gene Schmierer | Opinion | Enticing children over the internet
    Nov 20, 2014 | 39622 | State v. Jonathan Earl Folk | Opinion | Lewd conduct with child under sixteen
    Nov 12, 2014 | 41173 | State v. Robert Louis Stevenson | Opinion | Order denying motion for credit for time served
    Nov 6, 2014 | 41221 | State v. Jay Alton Roach | Opinion | DUI - Order excluding expert testimony
    Nov 6, 2014 | 40930 | State v. William Jack Bias | Opinion | DUI
    Nov 3, 2014 | 40091 | State v. Richard Allen Larson | Opinion | SUBSTITUTE OPINION. Aggravated Assault. Prior Opinion of 8/15/14 is WITHDRAWN.
    October 31, 2014 | 41365 | State v. Jeffrey J. Hughes | Opinion | State appeals dismissal of two felony counts - taking wildlife
    October 30, 2014 | 41533 | State v. Junior Larry Hillbroom | Opinion | No contact order
    October 22, 2014 | 40915/41205 | State v. Aaron Louis Bitkoff | Opinion | Credit for time served
    October 22, 2014 | 40751 | Ernesto Garza Lopez | Opinion | Post Conviction - Felony domestic batery
    October 22, 2014 | 40824 | Michael Parvin v. State | Opinion | Post Conviction - Lewd conduct with a child under sixteen
    October 20, 2014 | 41923 | State v. Christopher D. Griffith | Opinion | Motion to correct illegal sentence - First Degree Murder
    October 15, 2014 | 41534 | State v. Nathan David Neal | Opinion | Order suppressing evidence
    October 10, 2014 | 40769 | Larry Severson v. State | Opinion | First Degree Murder
    October 8, 2014 | 41431 | State v. Justin Lee Pedersen | Opinion | Motion to suppress
    October 8, 2014 | 40661/40828 | Gregory Joseph Nelson v. State | Opinion | Kidnapping; lewd conduct with a minor
    October 8, 2014 | 41241 | State v. Richard L. Beck | Opinion | Motion to suppress
    October 2, 2014 | 41535 | State v. Alfredo Lopez Rocha | Opinion | DUI
    Sept 29, 2014 | 40682 | State v. Anthony Edward Ortega | - Opinion | Felony injury to a child
    Sept 24, 2014 | 41541 | State v. Troy Cameron Young | - Opinion | Domestic battery in the presence of a child
    Sept 24, 2014 | 41660 | State v. Jeffrey Alan Denny | - Opinion | Credit for time served
    Sept 24, 2014 | 41046 | State v. Matthew O. Brooks | - Opinion | Possession of controlled substance
    Sept 24, 2014 | 40662 | State v. Justin B. Miller | - Opinion | Aggravated assault & battery
    Sept 18, 2014 | 41489 | State v. Big Dawg | - Opinion | Bail Bonds appeals partial exoneration
    Sept 8, 2014 | 39745 | Daniel Lee Dixon v. State | - Opinion | Post Conviction - Lewd conduct with a minor under sixteen
    Sept 2, 2014 | 41358 | State v. Marvin Orellana-Castro | - Opinion | Lewd conduct and sexual abuse of a minor
    Sept 2, 2014 | 41449 | Sean M. Cook v. State | - Opinion | State appeals judgment granting Post Conviction relief
    Aug 22, 2014 | 41114 | State v. Andrew Taylor | - Opinion | Possession - Meth
    Aug 22, 2014 | 41147 | State v. Connor G. Spies | - Opinion | Motion to suppress - Possession
    Aug 22, 2014 | 40777 | Popoca-Garcia v. State | - Opinion | Substitute Opinion - Appeal from denial of Post Conviction petition for relief from plea resulting in deportation.
    Aug 20, 2014 | 39672 | State v. Gutierrez-Medina | - Opinion | Post Conviction - Delivery of controlled substance
    Aug 20, 2014 | 41161 | State v. Doe (13-14) | - Opinion | Juvenile - Malicious injury to proerty
    Aug 13, 2014 | 41499 | James Dee Olsen v. State | - Opinion | Post Conviction - DUI
    Aug 12, 2014 | 41378 | State v. Michael Jay Freitas | - Opinion | Transferring water in violation of city ordinance
    July 30, 2014 | 40291 | State v. Benjamin Patrick Dugan | - Opinion | Injuring jails
    July 24, 2014 | 39876 | State v. Rey Alfredo Ornelas | - Opinion | Lewd conduct with minor child
    July 24, 2014 | 41428 | State v. Desiree B. Eliasen | - Opinion | Second degree stalking
    July 24, 2014 | 40475 | State v. George Alan Kapelle | - Opinion | This is a Substitute Opinion. Denial of motion to suppress
    July 18, 2014 | 40963 | Harvey L. Mahler v. State | - Opinion | Post Conviction - Lewd conduct with a minor
    July 18, 2014 | 41235 | Lee Edd Green, Jr. v. State | - Opinion | Post Conviction - Lewd conduct with a minor
    July 10, 2014 | 41402 | State v. Dennis Earl Hiebert | - Opinion | Possession of controlled substance
    July 10, 2014 | 41165 | State v. Lloyd Hardin McNeil | - Opinion | Order of restitution
    July 9, 2014 | 41270 | State v. Christopher T. Weaver | - Opinion | Order of restitution
    July 3, 2014 | 41325 | State v. Heidi H. Swenson | -Opinion | DUI-Administration of breath test
    July 2, 2014 | 40924 | Marc Edward Klein v. State | - Opinion | Post Conviction - Vehicular manslaughter
    June 30, 2014 | 39161 | State v. Arlyn V. Orr | - Opinion | DUI
    June 13, 2014 | 39847 | State v. Martin Edmo Ish | - Opinion | Controlled Sub.
    May 30, 2014 | 40720 | State v. Shawn O'Shay Davis, II | - Opinion | Grand Theft
    May 23, 2014 | 41168 | State v. Johnson | - Opinion | State's Appeal of Acquittal
    May 22, 2014 | 40419 | State v. Allen Keith Clontz | - Opinion | DUI
    May 20, 2014 | 41158 | State v. Jose Perez-Jungo | - Opinion | Controlled Sub.
    May 19, 2014 | 40941 | State v. Kenny Struhs | - Opinion | Vehicular Manslaughter
    May 12, 2014 | 40696 | State v. Allen | - Opinion | Motions for Relief and to Seal
    May 12, 2014 | 40175 | State v. Ruggiero | - Opinion | State Appeals Dismissal SUB
    May 7, 2014 | 41212 | State v. Stephen D. L'Abbe | - Opinion | Speeding
    May 6, 2014 | 40950 | State v. Mark C. Hunter | - Opinion | Motion to Suppress - DUI
    Apr 30, 2014 | 40026 | State v. Hamlin | - Opinion | Sexual Abuse - Vulnerable
    Apr 25, 2014 | 39207 | Woodrow Grant v. State | - Opinion | Post Conviction - Battery
    Apr 22, 2014 | 39684 | State v. Frank D. Marks | - Opinion | Lewd Conduct
    Apr 18, 2014 | 40985 | State v. Kevin Michael Nicolescu | - Opinion | DUI
    Apr 17, 2014 | 40423 | State v. Santos Tena | - Opinion | Controlled Sub.
    Apr 1, 2014 | 40995 | State v. Nikolas Sherman | - Opinion | Controlled Sub.
    Mar 28, 2014 | 40222 | State v. Wayne D. Anderson | - Opinion | Lewd Conduct
    Mar 27, 2014 | 39547 | Miguel C. Joyner v. State | - Opinion | No Contact (PC)
    Mar 26, 2014 | 39529 | State v. Valentin Calvillo | - Opinion | Lewd Conduct
    Mar 26, 2014 | 40811 | Cecil G. Daniels v. State | - Opinion | DUI
    Mar 25, 2014 | 40544 | State v. Robert Javier Garcia, Jr. | - Opinion |
    Mar 17, 2014 | 40471/40472 | Kent Hall v. State | - Opinion | Post-Conviction - Possession
    Mar 10, 2014 | 40506 | State v. Jacob M. Torrez | - Opinion | Aggravated DUI
    Feb 28, 2014 | 40223/40224 | State v. Rafael Galvan | - Opinion | Stalking
    Feb 28, 2014 | 40718 | State v. Gregory Scott McAmis | - Opinion | Grand Theft
    Feb 24, 2014 | 38123 | State v. Timothy Nichols | - Opinion | Statutory Rape
    Feb 21, 2014 | 40289 | State v. Derek Edward Moad | - Opinion | Male Rape
    Feb 20, 2014 | 40503 | State v. Pierre J. Saviers | - Opinion | No-Contact
    Feb 11, 2014 | 40416 | State v. Bryce S. Mendel | - Opinion | Controlled Sub
    Feb 11, 2014 | 40428 | State v. Morgan C. Alley | - Opinion | Controlled Sub
    Feb 10, 2014 | 40241 | State v. Rhonda Trusdall | - Opinion | DUI
    Feb 10, 2014 | 39933 | State v. Brandon Eddins | - Opinion | Assault
    Feb 5, 2014 | 40673 | State v. Albert Ray Moore | - Opinion | Credit for Time Served
    Feb 4, 2014 | 39811 | State v. Martin C. Cardoza | - Opinion | Trafficking
    Feb 4, 2014 | 39255/40628 | State v. Lee Odell Fair | - Opinion | Assault
    Jan 24, 2014 | 40616 | State v. Charles A. Vaughn, Jr. | - Opinion | No Contact
    Jan 17, 2014 | 39219 | State v. Kristi L. Hurles | - Opinion | Grand Theft
    Jan 10, 2014 | 40477 | State v. Teddy Edghill | - Opinion | [SUBSTITUTE]
    Jan 10, 2014 | 40634 | State v. Jacob Jerome Buck | - Opinion | Possession
    Jan 6, 2014 | 40359 | State v. Joseph Thomas Iverson | - Opinion | Battery
    Dec 30, 2013 | 39426/39427 | State v. Chase Dalton Gillespie | - Opinion | Sexually Exploitative
    Dec 30, 2013 | 40353 | Wally Kay Schultz v. State | - Opinion | Post-Conviction
    Dec 23, 2013 | 39484/39485/39486 | State v. Shawn M. Kesling | - Opinion | Order Revoking Probation
    Dec 19, 2013 | 40239 | State v. Derek W. Howard | - Opinion | Motion to Suppress
    Dec 12, 2013 | 40417 | Gregory S. McAmis v. State | - Opinion | Grand Theft
    Dec 10, 2013 | 39908 | State v. Daniel L. Widner | - Opinion | Trafficking
    Dec 10, 2013 | 39218 | Edward Stevens v. State | - Opinion | Post-Conviction
    Nov 26, 2013 | 39903 | State v. Donald Houser | - Opinion | Assault
    Nov 21, 2013 | 38554 | State v. Darren Carmouche | - Opinion | Battery
    Nov 14, 2013 | 39287 | State v. Franklin Osterhoudt | - Opinion | Rape
    Nov 14, 2013 | 38896 | State v. William Franklin Wolfe | - Opinion | [SUBSTITUTE] Rule 35
    Nov 12, 2013 | 40135 | State v. Juan L. Juarez | - Opinion | DUI
    Nov 8, 2013 | 39881 | State v. Lloyd Hardin McNeil | - Opinion | Manslaughter
    Oct 25, 2013 | 39954 | State v. Garry K. Widmyer | - Opinion | Lewd Conduct
    Oct 25, 2013 | 39943 | State v. J. Bradshaw | - Opinion | Destruction of Evidence
    Oct 22, 2013 | 40069 | State v. Kori Lynn Ward | - Opinion | Order Supressing
    Oct 22, 2013 | 39284 | State v. Daniel & Kathleen Bergerud | - Opinion |
    Oct 7, 2013 | 40165 | State v. Ricardo Ozuna, Jr. | - Opinion | Lewd
    Sept 19, 2013 | 39226 | State v. Mark L. Ellis | - Opinion | Motion to Supress
    Sept 6, 2013 | 38347 | State v. Keith Allan Brown | - Opinion | Manslaughter
    Sept 6, 2013 | 39682/39683 | State v. Moses Olivas, Jr. | - Opinion | Sex Offender
    Sept 5, 2013 | 39891 | State v. Gary L. Schall | - Opinion | DUI
    July 23, 2013 | 38813 | State v. Tankovich | - Opinion | Malicious Harrassment
    July 17, 2013 | 36427 | State v. Leotis B. Branigh, III | - Opinion | Murder
    July 12, 2013 | 39139 | State v. Elias | - Opinion | Forcible Penetration
    July 11, 2013 | 40244 | State v. Tracy Lorene Davis | - Opinion | DUI

- Printer-friendly version
- PDF version